<?php

namespace Drupal\advanced_email_validation\Plugin\Validation\Constraint;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\advanced_email_validation\EmailValidatorWrapperService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Class AdvancedEmailValidationValidator
 */
class AdvancedEmailValidationValidator extends ConstraintValidator implements ContainerInjectionInterface {

  protected $emailValidator;

  public function __construct(EmailValidatorWrapperService $emailValidatorWrapper) {
    $this->emailValidator = $emailValidatorWrapper;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('advanced_email_validation.validator')
    );
  }

  public function validate($value, Constraint $constraint) {
    $result = $this->emailValidator->validate($value->getString());

    switch ($result) {
      case EmailValidatorWrapperService::ADVANCED_EMAIL_VALIDATION_INVALID :
        $this->context->addViolation($constraint->invalidEmail);
        break;
      case EmailValidatorWrapperService::ADVANCED_EMAIL_VALIDATION_FREE :
        $this->context->addViolation($constraint->freeEmail);
        break;
      case EmailValidatorWrapperService::ADVANCED_EMAIL_VALIDATION_DISPOSABLE :
        $this->context->addViolation($constraint->disposableEmail);
        break;
      case EmailValidatorWrapperService::ADVANCED_EMAIL_VALIDATION_BANNED :
        $this->context->addViolation($constraint->bannedEmail);
        break;
    }
  }

}
